==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesVls.php <==
<?php
/** West-Vlams (West-Vlams)
 *
 * @ingroup Language
 * @file
 *
 * @author Tbc
 * @author לערי ריינהארט
 */

$fallback = 'nl';

$namespaceNames = array(
	NS_MEDIA          => 'Media',
	NS_SPECIAL        => 'Specioal',
	NS_MAIN           => '',
	NS_TALK           => 'Discuusje',
	NS_USER           => 'Gebruker',
	NS_USER_TALK      => 'Discuusje_gebruker',
	# NS_PROJECT set by $wgMetaNamespace
	NS_PROJECT_TALK   => 'Discuusje_$1',
	NS_IMAGE          => 'Ofbeeldienge',
	NS_IMAGE_TALK     => 'Discuusje_ofbeeldienge',
	NS_MEDIAWIKI      => 'MediaWiki',
	NS_MEDIAWIKI_TALK => 'Discuusje_MediaWiki',
	NS_TEMPLATE       => 'Patrôon',
	NS_TEMPLATE_TALK  => 'Discuusje_patrôon',
	NS_HELP           => 'Ulpe',
	NS_HELP_TALK      => 'Discuusje_ulpe',
	NS_CATEGORY       => 'Categorie',
	NS_CATEGORY_TALK  => 'Discuusje_categorie',
);

$messages = array(
# Dates
'tuesday' => 'diensdag',

'newwindow' => '(opent in e nieuw veister)',
'mypage'    => 'Myn gebrukersblad',
'mytalk'    => 'Myn discuusjeblad',

'history_short' => 'Geschiedenisse',
'edit'          => "Bewerk'n",
'delete'        => 'Wegdoen',
'unprotect'     => 'beveiliginge wegdoen',
'newpage'       => 'Nieuw blad',
'toolbox'       => 'Ulpmiddeln',

# Login and logout pages
'logout' => 'Ofmeldn',

# Recent changes
'recentchanges' => 'Juste veranderd',

# Upload
'upload'            => 'Bestand toevoegn',
'uploadbtn'         => 'Bestand toevoegn',
'uploadnologin'     => 'Ge zyt nie angemeld',
'uploadlog'         => 'logboek upgeloade bestandn',
'uploadlogpage'     => 'Logboek upgeloade bestandn',
'uploadlogpagetext' => 'Hier stoa e lyste met de mêest recente upgeloade bestandn.',
'uploadedfiles'     => 'Upgeloade bestandn',
'uploadedimage'     => '"[[$1]]" upgeload',

# Unwatched pages
'unwatchedpages' => "Pagina's die ip niemands volglyste stoan",

# Miscellaneous special pages
'newpages'          => 'Nieuwe bloadn',
'newpages-username' => 'Gebrukersnoame:',

# Watchlist
'mywatchlist' => 'Myn volglyste',
'watch'       => 'Volgn',
'unwatch'     => 'Nie volgn',

# Displayed when you click the "watch" button and it's in the process of watching
'unwatching' => 'Stoppn me volgn...',

# Undelete
'undelete'               => 'Weggedoane bloadn bekykn',
'undeletepage'           => 'Weggedoane bloadn erstelln of bekykn',
'undeletehistorynoadmin' => "'t Artikel is weggedoan. De reden davôorn ku je zien in de soamnvattienge ieronder, tôpe me uutleg over wie dat 't blad bewerkt èt vôorn dat weggedoan es gewist. Den tekst van die weggedoane versies kan allêene door sysops gelezen wordn.",
'undeletebtn'            => 'Erstelln',
'undeletedarticle'       => '"[[$1]]" ersteld',
'undeletedfiles'         => '{{PLURAL:$1|1 bestand|$1 bestandn}} ersteld',

# Contributions
'mycontris' => 'Myn bydroagn',
'uctop'     => '(latste veranderienge)',

# Move page
'delete_and_move' => 'Wegdoen en ernoemn',

# Tooltip help for the actions
'tooltip-n-mainpage' => "Noar 't voorblad goane",

# Special:Newimages
'newimages' => 'Nieuwe ofbeeldiengn',

);

==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesVls.php <==
<?php
/** West-Vlams (West-Vlams)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Tbc
 * @author לערי ריינהארט
 */

$fallback = 'nl';

$namespaceNames = array(
	NS_MEDIA          => 'Media',
	NS_SPECIAL        => 'Specioal',
	NS_MAIN           => '',
	NS_TALK           => 'Discuusje',
	NS_USER           => 'Gebruker',
	NS_USER_TALK      => 'Discuusje_gebruker',
	# NS_PROJECT set by $wgMetaNamespace
	NS_PROJECT_TALK   => 'Discuusje_$1',
	NS_FILE           => 'Ofbeeldienge',
	NS_FILE_TALK      => 'Discuusje_ofbeeldienge',
	NS_MEDIAWIKI      => 'MediaWiki',
	NS_MEDIAWIKI_TALK => 'Discuusje_MediaWiki',
	NS_TEMPLATE       => 'Patrôon',
	NS_TEMPLATE_TALK  => 'Discuusje_patrôon',
	NS_HELP           => 'Ulpe',
	NS_HELP_TALK      => 'Discuusje_ulpe',
	NS_CATEGORY       => 'Categorie',
	NS_CATEGORY_TALK  => 'Discuusje_categorie',
);

$messages = array(
# Dates
'tuesday' => 'diensdag',

'newwindow' => '(opent in e nieuw veister)',
'mypage'    => 'Myn gebrukersblad',
'mytalk'    => 'Myn discuusjeblad',

'history_short' => 'Geschiedenisse',
'edit'          => "Bewerk'n",
'delete'        => 'Wegdoen',
'unprotect'     => 'beveiliginge wegdoen',
'newpage'       => 'Nieuw blad',
'toolbox'       => 'Ulpmiddeln',

# Login and logout pages
'logout' => 'Ofmeldn',

# Recent changes
'recentchanges' => 'Juste veranderd',

# Upload
'upload'            => 'Bestand toevoegn',
'uploadbtn'         => 'Bestand toevoegn',
'uploadnologin'     => 'Ge zyt nie angemeld',
'uploadlog'         => 'logboek upgeloade bestandn',
'uploadlogpage'     => 'Logboek upgeloade bestandn',
'uploadlogpagetext' => 'Hier stoa e lyste met de mêest recente upgeloade bestandn.',
'uploadedfiles'     => 'Upgeloade bestandn',
'uploadedimage'     => '"[[$1]]" upgeload',

# Unwatched pages
'unwatchedpages' => "Pagina's die ip niemands volglyste stoan",

# Miscellaneous special pages
'newpages'          => 'Nieuwe bloadn',
'newpages-username' => 'Gebrukersnoame:',

# Special:Log/newusers
'newuserlogpage'          => 'Logboek nieuwe gebrukers',
'newuserlog-create-entry' => 'Nieuwe gebruker',

# Watchlist
'mywatchlist' => 'Myn volglyste',
'watch'       => 'Volgn',
'unwatch'     => 'Nie volgn',

# Displayed when you click the "watch" button and it is in the process of watching
'unwatching' => 'Stoppn me volgn...',

# Undelete
'undelete'               => 'Weggedoane bloadn bekykn',
'undeletepage'           => 'Weggedoane bloadn erstelln of bekykn',
'undeletehistorynoadmin' => "'t Artikel is weggedoan. De reden davôorn ku je zien in de soamnvattienge ieronder, tôpe me uutleg over wie dat 't blad bewerkt èt vôorn dat weggedoan es gewist. Den tekst van die weggedoane versies kan allêene door sysops gelezen wordn.",
'undeletebtn'            => 'Erstelln',
'undeletedarticle'       => '"[[$1]]" ersteld',
'undeletedfiles'         => '{{PLURAL:$1|1 bestand|$1 bestandn}} ersteld',

# Contributions
'mycontris' => 'Myn bydroagn',
'uctop'     => '(latste veranderienge)',

# Move page
'delete_and_move' => 'Wegdoen en ernoemn',

# Tooltip help for the actions
'tooltip-n-mainpage' => "Noar 't voorblad goane",

# Special:NewFiles
'newimages' => 'Nieuwe ofbeeldiengn',

);
